"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.commandNames = exports.rcOptionsTypes = void 0;
exports.cliOptionsTypes = cliOptionsTypes;
exports.help = help;
exports.handler = handler;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const cli_utils_1 = require("@pnpm/cli-utils");
const error_1 = require("@pnpm/error");
const write_project_manifest_1 = require("@pnpm/write-project-manifest");
const render_help_1 = __importDefault(require("render-help"));
const utils_1 = require("./utils");
exports.rcOptionsTypes = cliOptionsTypes;
function cliOptionsTypes() {
    return {};
}
exports.commandNames = ['init'];
function help() {
    return (0, render_help_1.default)({
        description: 'Create a package.json file',
        descriptionLists: [],
        url: (0, cli_utils_1.docsUrl)('init'),
        usages: ['pnpm init'],
    });
}
async function handler(opts, params) {
    if (params?.length) {
        throw new error_1.PnpmError('INIT_ARG', 'init command does not accept any arguments', {
            hint: `Maybe you wanted to run "pnpm create ${params.join(' ')}"`,
        });
    }
    // Using cwd instead of the dir option because the dir option
    // is set to the first parent directory that has a package.json file.
    const manifestPath = path_1.default.join(process.cwd(), 'package.json');
    if (fs_1.default.existsSync(manifestPath)) {
        throw new error_1.PnpmError('PACKAGE_JSON_EXISTS', 'package.json already exists');
    }
    const manifest = {
        name: path_1.default.basename(process.cwd()),
        version: '1.0.0',
        description: '',
        main: 'index.js',
        scripts: {
            test: 'echo "Error: no test specified" && exit 1',
        },
        keywords: [],
        author: '',
        license: 'ISC',
    };
    const config = await (0, utils_1.parseRawConfig)(opts.rawConfig);
    const packageJson = { ...manifest, ...config };
    await (0, write_project_manifest_1.writeProjectManifest)(manifestPath, packageJson, {
        indent: 2,
    });
    return `Wrote to ${manifestPath}

${JSON.stringify(packageJson, null, 2)}`;
}
//# sourceMappingURL=init.js.map